@@ -108,7 +108,7 @@ dateInfluence.BchronologyRun <- function(bchrRun,
         outlierProbs = outlierProbs[-whichDate],
         predictPositions = closestPosition,
         pathToCalCurves = pathToCalCurves,
-        jitterPositions = jitterPositions,
+        artificialThickness = artificialThickness,
         iterations = iterations,
         burn = burn,
         thin = thin,
@@ -179,7 +179,7 @@ dateInfluence.BchronologyRun <- function(bchrRun,
         outlierProbs = outlierProbs[-whichDate],
         predictPositions = positions[whichDate],
         pathToCalCurves = pathToCalCurves,
-        jitterPositions = jitterPositions,
+        artificialThickness = artificialThickness,
         iterations = iterations,
         burn = burn,
         thin = thin,
@@ -256,7 +256,7 @@ dateInfluence.BchronologyRun <- function(bchrRun,
           outlierProbs = outlierProbs[-whichDate],
           predictPositions = closestPosition,
           pathToCalCurves = pathToCalCurves,
-          jitterPositions = jitterPositions,
+          artificialThickness = artificialThickness,
           iterations = iterations,
           burn = burn,
           thin = thin,
@@ -334,7 +334,7 @@ dateInfluence.BchronologyRun <- function(bchrRun,
           outlierProbs = outlierProbs[-whichDate],
           predictPositions = closestPosition,
           pathToCalCurves = pathToCalCurves,
-          jitterPositions = jitterPositions,
+          artificialThickness = artificialThickness,
           iterations = iterations,
           burn = burn,
           thin = thin,
