@@ -62,8 +62,8 @@ plot.BchronRSLRun <-
       xgrid <- seq(max(ageAll), min(ageAll), length = 100) / 1000
 
       predLines <- matrix(NA, ncol = length(xgrid), nrow = nrow(x$samples))
-      degmat <- matrix(rep(0:(x$degree), length(xgrid) * (x$degree + 1)),
-        nrow = length(xgrid), ncol = x$degree + 1, byrow = TRUE
+      degmat <- matrix(rep(0:(x$degree), each = length(xgrid)),
+        nrow = length(xgrid), ncol = x$degree + 1
       )
       X.pred <- matrix(rep(xgrid - x$const, x$degree + 1), ncol = x$degree + 1)
       X.pred <- (X.pred^degmat)
@@ -96,8 +96,12 @@ plot.BchronRSLRun <-
       # No need for ellipses, just create the plot
       xgrid <- seq(max(ageAll), min(ageAll), length = 100) / 1000
 
-      degmat <- matrix(rep(0:(x$degree), length(xgrid) * (x$degree + 1)), nrow = length(xgrid), ncol = x$degree + 1, byrow = TRUE)
-      degmat_rate <- matrix(rep(0:(x$degree), length(xgrid) * (x$degree + 1)), nrow = length(xgrid), ncol = x$degree + 1, byrow = TRUE) - 1
+      degmat <- matrix(rep(0:(x$degree), each = length(xgrid)),
+        nrow = length(xgrid), ncol = x$degree + 1
+      )
+      degmat_rate <- matrix(rep(0:(x$degree), each = length(xgrid)),
+        nrow = length(xgrid), ncol = x$degree + 1
+      ) - 1
       X.pred <- matrix(rep(xgrid - x$const, x$degree + 1), ncol = x$degree + 1)
       X.pred <- -degmat * (X.pred^degmat_rate)
       predLines <- matrix(NA, ncol = length(xgrid), nrow = nrow(x$samples))
@@ -132,9 +136,19 @@ plot.BchronRSLRun <-
       xgrid <- seq(max(ageAll), min(ageAll), length = 100) / 1000
 
       predLines <- matrix(NA, ncol = length(xgrid), nrow = nrow(x$samples))
-      degmat <- matrix(rep(0:(x$degree), length(xgrid) * (x$degree + 1)), nrow = length(xgrid), ncol = x$degree + 1, byrow = TRUE)
-      degmat_rate <- matrix(rep(0:(x$degree), length(xgrid) * (x$degree + 1)), nrow = length(xgrid), ncol = x$degree + 1, byrow = TRUE) - 1
-      degmat_accel <- matrix(rep(0:(x$degree), length(xgrid) * (x$degree + 1)), nrow = length(xgrid), ncol = x$degree + 1, byrow = TRUE) - 2
+
+      degmat <- matrix(rep(0:(x$degree), each = length(xgrid)),
+        nrow = length(xgrid), ncol = x$degree + 1
+      )
+      degmat_rate <- matrix(rep(0:(x$degree), each = length(xgrid)),
+        nrow = length(xgrid), ncol = x$degree + 1
+      ) - 1
+      degmat <- matrix(rep(0:(x$degree), each = length(xgrid)),
+        nrow = length(xgrid), ncol = x$degree + 1
+      )
+      degmat_accel <- matrix(rep(0:(x$degree), each = length(xgrid)),
+        nrow = length(xgrid), ncol = x$degree + 1
+      ) - 2
       X.pred <- matrix(rep(xgrid - x$const, x$degree + 1), ncol = x$degree + 1)
       X.pred <- degmat * (degmat - 1) * (X.pred^degmat_accel)
 
