@@ -16,7 +16,6 @@ co(
       positionThicknesses = thickness,
       ids = id,
       calCurves = calCurves,
-      jitterPositions = TRUE,
       predictPositions = TestRSLData$Depth,
       iterations = 100,
       burn = 20,
@@ -50,8 +49,8 @@ test_that("summary and plot RSL functions", {
   p <- plot(RSLrun, type = "rate") + ggtitle("Rate of RSL change") +
     ylab("Rate (mm per year)")
   expect_s3_class(p, "ggplot")
-  p <- plot(RSLrun, type = "accel") + ggtitle("Rate of RSL change") +
-    ylab("Rate (mm per year)")
+  p <- plot(RSLrun, type = "accel") + ggtitle("Acceleration of RSL change") +
+    ylab("Acceleration (mm per year per year)")
   expect_s3_class(p, "ggplot")
   expect_output(summary(RSLrun, type = "RSL", age_grid = seq(0, 2000, by = 250)))
   expect_output(summary(RSLrun, type = "parameters", age_grid = seq(0, 2000, by = 250)))
